@@ -7,12 +7,12 @@ from redis import Redis as BaseRedis
 __all__ = ('Redis', )
 
 
-class Redis(BaseRedis):
+class Redis(object):
     """
     Simple object to initialize redis client using settings from Flask
     application.
     """
-    def __init__(self, app=None):
+    def __init__(self, app=None, config_prefix=None):
         """
         Overwrite default ``Redis.__init__`` method, read all necessary
         settings from Flask app config instead of positional and keyword args.
@@ -62,16 +62,24 @@ class Redis(BaseRedis):
 
         """
         if app is not None:
-            self.init_app(app)
+            self.init_app(app, config_prefix)
 
-        setattr(self, '_flask_app', app)
-
-    def init_app(self, app):
+    def init_app(self, app, config_prefix=None):
         """
         Actual method to read redis settings from app configuration.
         """
+        if not 'redis' in app.extensions:
+            app.extensions['redis'] = {}
+
+        self.config_prefix = config_prefix = config_prefix or 'REDIS'
+
+        if config_prefix in app.extensions['redis']:
+            raise ValueError('Already registered config prefix {0!r}.'.
+                             format(config_prefix))
+
         converters = {'port': int}
-        url = app.config.get('REDIS_URL')
+        key = lambda suffix: u'{0}_{1}'.format(config_prefix, suffix)
+        url = app.config.get(key('URL'))
 
         if url:
             urlparse.uses_netloc.append('redis')
@@ -79,19 +87,19 @@ class Redis(BaseRedis):
 
             # URL could contains host, port, user, password and db
             # values. Store their to config
-            app.config['REDIS_HOST'] = url.hostname
-            app.config['REDIS_PORT'] = url.port
-            app.config['REDIS_USER'] = url.username
-            app.config['REDIS_PASSWORD'] = url.password
+            app.config[key('HOST')] = url.hostname
+            app.config[key('PORT')] = url.port
+            app.config[key('USER')] = url.username
+            app.config[key('PASSWORD')] = url.password
             db = url.path.replace('/', '')
-            app.config['REDIS_DB'] = db if db.isdigit() else None
+            app.config[key('DB')] = db if db.isdigit() else None
 
         spec = inspect.getargspec(BaseRedis.__init__)
         args = set(spec.args).difference(set(['self']))
         kwargs = {}
 
         for arg in args:
-            redis_arg = 'REDIS_%s' % arg.upper()
+            redis_arg = key(arg.upper())
 
             if not redis_arg in app.config:
                 continue
@@ -103,4 +111,17 @@ class Redis(BaseRedis):
 
             kwargs.update({arg: value})
 
-        super(Redis, self).__init__(**kwargs)
+        self.connection = redis = BaseRedis(**kwargs)
+        app.extensions['redis'][config_prefix] = redis
+
+        self._include_redis_methods(redis)
+
+    def _include_redis_methods(self, redis):
+        """
+        Include redis methods as current instance methods.
+        """
+        for attr in dir(redis):
+            value = getattr(redis, attr)
+            if attr.startswith('_') or not callable(value):
+                continue
+            self.__dict__[attr] = value
